# Define required providers
terraform {
  required_version = ">= 0.14.0"
  required_providers {
    openstack = {
      source  = "terraform-provider-openstack/openstack"
      version = "~> 1.53.0"
    }
  }
}

data "terraform_remote_state" "privnet_dns_router" {
  backend = "local"

  config = {
    path = "../project-setup/terraform.tfstate"
  }
}


#
# Uses common_variables as module
#
module "common_variables" {
  source = "../../modules/common_variables"
}


#
# Creates the server group "geoportal"
#
resource "openstack_compute_servergroup_v2" "geoportal" {
  name     = "geoportal"
  policies = [module.common_variables.policy_list.soft_anti_affinity]
}


#
# Uses the "generic_smartgears_service" as module
#
module "smartgears_service_generic" {
  source = "../../modules/generic_smartgears_service"

  smartgears_service_instances_map = {
    geoportal_service = {
      name              = "geoportal-cms",
      description       = "The Geoportal instance",
      flavor            = module.common_variables.flavor_list.m1_medium,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [openstack_compute_servergroup_v2.geoportal.id],
      image_ref         = module.common_variables.ubuntu_1804
    }
  }
}
