# Define required providers
terraform {
  required_version = ">= 0.14.0"
  required_providers {
    openstack = {
      source  = "terraform-provider-openstack/openstack"
      version = "~> 1.53.0"
    }
  }
}

data "terraform_remote_state" "privnet_dns_router" {
  backend = "local"

  config = {
    path = "../project-setup/terraform.tfstate"
  }
}


#
# Uses common_variables as module
#
module "common_variables" {
  source = "../../modules/common_variables"
}


module "geo_service" {

  source = "../../modules/geo_services"

  geo_service_instances_map = {
    geona = {
      name              = "geoserver-geona",
      description       = "Geoserver geona instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-geona_data_volume",
      vol_data_size     = "50"
    },
    esquiline = {
      name              = "geoserver-esquiline",
      description       = "Geoserver esquiline instance",
      flavor            = module.common_variables.flavor_list.m2_small,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-esquiline_data_volume",
      vol_data_size     = "20"
    },
    ariadne = {
      name              = "geoserver-ariadne",
      description       = "Geoserver ariadne instance",
      flavor            = module.common_variables.flavor_list.m2_small,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-ariadne_data_volume",
      vol_data_size     = "20"
    },
    grsf = {
      name              = "geoserver-grsf",
      description       = "Geoserver grsf instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-grsf_data_volume",
      vol_data_size     = "40"
    },
    protectedareaimpactmaps = {
      name              = "geoserver-protectedareaimpactmaps",
      description       = "Geoserver protectedareaimpactmaps instance",
      flavor            = module.common_variables.flavor_list.c1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-protectedareaimpactmaps_data_volume",
      vol_data_size     = "70"
    }
    sdi-lab = {
      name              = "geoserver-sdi-lab",
      description       = "Geoserver sdi-lab instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-sdi-lab_data_volume",
      vol_data_size     = "100"
    }
    tunaatlas = {
      name              = "geoserver-tunaatlas",
      description       = "Geoserver tunaatlas instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-tunaatlas_data_volume",
      vol_data_size     = "60"
    }
    wecafc-firms = {
      name              = "geoserver-wecafc-firms",
      description       = "Geoserver wecafc-firms instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-wecafc-firms_data_volume",
      vol_data_size     = "40"
    }
    aquacultureatlas = {
      name              = "geoserver-aquacultureatlas",
      description       = "Geoserver aquacultureatlas instance",
      flavor            = module.common_variables.flavor_list.m1_large,
      networks          = ["d4s-dev-cloud-main", module.common_variables.networks_list.shared_postgresql],
      security_groups   = [module.common_variables.security_group_list.default, module.common_variables.security_group_list.http_and_https_from_the_load_balancers],
      server_groups_ids = [],
      image_ref         = module.common_variables.ubuntu_1804
      vol_data_name     = "geoserver-aquacultureatlas_data_volume",
      vol_data_size     = "50"
    }

  }


}
