# Define required providers
terraform {
  required_version = ">= 0.14.0"
  required_providers {
    openstack = {
      source  = "terraform-provider-openstack/openstack"
      version = "~> 1.53.0"
    }
  }
}

data "terraform_remote_state" "privnet_dns_router" {
  backend = "local"

  config = {
    path = "../project-setup/terraform.tfstate"
  }
}

module "liferay" {
  source                      = "../../modules/liferay"
  default_security_group_name = "default_for_all"

  # Provided in the output of the project setup
  main_private_network_id = "23fd8a99-d551-4ada-8d3a-9859542ebb8c"
  main_private_subnet_id  = "cd77a2fd-4a36-4254-b1d0-70b3874c6d04"
  dns_zone_id             = "c1a4b4bc-f167-4387-855d-38f0f99ca05c"

  os_project_data = {
    id = "6fdc02e2827b405dad99f34698659742"
  }

  dns_zone = {
    zone_name   = "cloud-pre.d4science.org."
    email       = "postmaster@isti.cnr.it"
    description = "DNS primary zone for the d4s-pre-cloud project"
    ttl         = 8600
    id          = "c1a4b4bc-f167-4387-855d-38f0f99ca05c"
  }

  main_private_network = {
    name        = "d4s-pre-cloud-main"
    description = "D4Science Preprod private network (use this as the main network)"
  }

  main_private_subnet = {
    name             = "d4s-pre-cloud-main-subnet"
    description      = "D4Science Preprod main private subnet"
    cidr             = "10.1.32.0/22"
    gateway_ip       = "10.1.32.1"
    allocation_start = "10.1.32.100"
    allocation_end   = "10.1.35.254"
  }

  external_router = {
    name        = "d4s-pre-cloud-external-router"
    description = "D4Science Preprod main router"
    id          = "cc26064a-bb08-4c0b-929f-d0cb39f934a3"
  }

  basic_services_ip = {
    ca                = "10.1.32.4"
    ca_cidr           = "10.1.32.4/32"
    ssh_jump          = "10.1.32.5"
    ssh_jump_cidr     = "10.1.32.5/32"
    prometheus        = "10.1.32.10"
    prometheus_cidr   = "10.1.32.10/32"
    haproxy_l7_1      = "10.1.32.11"
    haproxy_l7_1_cidr = "10.1.32.11/32"
    haproxy_l7_2      = "10.1.32.12"
    haproxy_l7_2_cidr = "10.1.32.12/32"
    octavia_main      = "10.1.32.20"
    octavia_main_cidr = "10.1.32.20/32"
  }

  main_haproxy_l7_ip = ["10.1.32.11", "10.1.32.12"]

  liferay_data = {
    affinity_policy = "soft-anti-affinity"
    srv_name        = "lr62"
    vm_count        = 2
    vm_flavor       = "m1.large"
    boot_vol_size   = 30
  }

  liferay_ip_addrs =  ["10.1.32.24", "10.1.32.25"]
}

